Merge branch 'refs/heads/t/play_fix'
[paraslash.git] / ggo.h
diff --git a/ggo.h b/ggo.h
index 12574dbada6ce84ca6ab7a571b4919923d80dfaa..9d9c5044db9a8c0fa4061bcd579f861c353d54ea 100644 (file)
--- a/ggo.h
+++ b/ggo.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2013 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2008-2014 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -16,6 +16,8 @@ struct ggo_help {
        const char **short_help;
        /** Like \a short_help, plus the \a details section. */
        const char **detailed_help;
+       /** The purpose text as specified in the ggo file. */
+       const char *purpose;
        /** Generated by gengetopt and exported via the *.cmdline.h file. */
        const char *usage;
        /** The description text given in the .ggo file. */
@@ -31,8 +33,8 @@ struct ggo_help {
 enum ggo_print_help_flags {
        /** Whether to print the short help or the detailed help. */
        GPH_DETAILED = 1 << 0,
-       /** Print the program or module name, git version and codename. */
-       GPH_PRINT_NAME_VERSION = 1 << 1,
+       /** Print the program or module name and the purpose text. */
+       GPH_PRINT_NAME_PURPOSE = 1 << 1,
        /** Print the synopsis. */
        GPH_PRINT_USAGE = 1 << 2,
        /** Print the description text. */
@@ -41,7 +43,7 @@ enum ggo_print_help_flags {
 
 /** Used to print the normal help of programs (--help) */
 #define GPH_STANDARD_FLAGS \
-       (GPH_PRINT_NAME_VERSION | GPH_PRINT_USAGE)
+       (GPH_PRINT_NAME_PURPOSE | GPH_PRINT_USAGE)
 
 /** Additional information for --detailed-help. */
 #define GPH_STANDARD_FLAGS_DETAILED \
@@ -59,6 +61,7 @@ enum ggo_print_help_flags {
                .prefix = #_prefix, \
                .short_help = _prefix ## _args_info_help, \
                .detailed_help = _prefix ## _args_info_detailed_help, \
+               .purpose = _prefix ## _args_info_purpose, \
                .usage = _prefix ## _args_info_usage, \
                .description = _prefix ## _args_info_description, \
        }